@@ -5,7 +5,7 @@ echo "" 												>> $EXTENSION/build_order.txt
 # Required
 [[ $(command -v curl) == "" ]] && echo "Installing curl" && extension --install curl && echo "Finished curl"
 [[ $(command -v derb) == "" ]] && echo "Installing icu" && extension --install icu && echo "Finished icu"
-[[ $(command -v libxml2) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
+[[ $(command -v xml2-config) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
 # Recommended
 if [[ $INSTALL_RECOMMENDED != false ]]; then 
 	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
